@@ -402,13 +402,15 @@ class FPDFRB(fpdf.FPDF):
         fpdf.FPDF.__init__(self, orientation=orientation, unit='pt', format=dimension)
         self.x = 0
         self.y = 0
-        # self.set_doc_option('core_fonts_encoding', 'windows-1252')
+        #self.set_doc_option('core_fonts_encoding', 'utf-8')
         # self.set_doc_option('encode_error_handling', encode_error_handling)
         self.loaded_images = dict()
         self.available_fonts = dict(
             courier=dict(standard_font=True),
             helvetica=dict(standard_font=True),
             times=dict(standard_font=True))
+        self.add_font('DejaVu', '', './reportbro_plus/fonts/DejaVuSansCondensed.ttf', uni=True)
+
         if additional_fonts:
             for additional_font in additional_fonts:
                 filename = additional_font.get('filename', '')
@@ -486,6 +488,7 @@ class FPDFRB(fpdf.FPDF):
             if underline:
                 style += 'U'
             fpdf.FPDF.set_font(self, family, style, size)
+            fpdf.FPDF.set_font(self, 'DejaVu', '', 14)
             return True
         else:
             return False
